#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-default-instances-dlist
version:              0.0.1.2
visibility:           public
id:                   data-default-instances-dlist-0.0.1.2-6FKP3eNqvpNKqcdbI8QHmF
key:                  data-default-instances-dlist-0.0.1.2-6FKP3eNqvpNKqcdbI8QHmF
license:              BSD-3-Clause
copyright:            (c) 2013 Lukas Mai
maintainer:           <lukasmai.403+hackage@gmail.com>
author:               Lukas Mai
synopsis:             Default instances for types in dlist
description:
    This module defines a '\''Default'\'' instance for the type '\''DList'\''.

category:             Data
abi:                  092f0113710b001e7d33fc4ecd0ee76b
exposed:              True
exposed-modules:      Data.Default.Instances.DList
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/data-default-instances-dlist-0.0.1.2

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/data-default-instances-dlist-0.0.1.2

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/data-default-instances-dlist-0.0.1.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-default-instances-dlist
hs-libraries:
    HSdata-default-instances-dlist-0.0.1.2-6FKP3eNqvpNKqcdbI8QHmF

depends:
    base-4.18.2.1 data-default-class-0.1.2.2-CDKXYK1wrFx3d5as0Pbjkc
    dlist-1.0-CwrBcgWkPAd5zJftecqL5r

haddock-interfaces:
    /usr/share/doc/haskell-data-default-instances-dlist/html/data-default-instances-dlist.haddock

haddock-html:         /usr/share/doc/haskell-data-default-instances-dlist/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

